import {
  select,
  csv,
  scaleLinear,
  scalePoint,
  extent,
  axisBottom,
  axisLeft,
} from 'd3';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let xColumn;
let yColumn;

const onXColumnClicked = (column) => {
  xColumn = column;
  render();
};
const onYColumnClicked = (column) => {
  yColumn = column;
  render();
};

const render = () => {
  select('#x-menu').call(dropdownMenu, {
    options: data.columns.slice(0, 4),
    onOptionClicked: onXColumnClicked,
    selectedOption: xColumn,
  });

  select('#y-menu').call(dropdownMenu, {
    options: data.columns.slice(0, 4),
    onOptionClicked: onYColumnClicked,
    selectedOption: yColumn,
  });

  svg.call(scatterPlot, {
    margin: {
      top: 30,
      right: 100,
      bottom: 70,
      left: 100,
    },
    width,
    height,
    data,
    xValue: (d) => d[xColumn],
    xAxisLabel: xColumn,
    yValue: (d) => d[yColumn],
    yAxisLabel: yColumn,
    colorLegendLabel: 'Classes',
    colorValue: (d) => d.class
  });
};

csv('iris.csv').then((loadedData) => {
  data = loadedData;
  data.forEach((d) => {
    d['sepal length'] = +d['sepal length'];
    d['sepal width'] = +d['sepal width'];
    d['petal length'] = +d['petal length'];
    d['petal width'] = +d['petal width'];
  });
  data.pop();
  xColumn = data.columns[0];
  yColumn = data.columns[1];
  render();
});
